@@ -8,8 +8,8 @@ Django-supervisor combines the process-managment awesomness of supervisord
 with the convenience of Django's management scripts.
 
 
-Why?
-----
+Rationale
+---------
 
 Running a Django project these days often entails much more than just starting
 up a webserver.  You might need to have Django running under FCGI or CherryPy,
@@ -30,6 +30,24 @@ processes required by your project as simple as::
     $ python myproject/manage.py supervisor
 
 
+Advantages
+----------
+
+Django-supervisor is admittedly quite a thin layer on top of the wonderful
+functionality provided by supervisord.  But by integrating tightly with
+Django's management scripts you gain several advantages:
+
+    * manage.py remains the single point of control for running your project.
+    * Running all those processes is just as easy in development as it
+      is in production.
+    * You get auto-reloading for *all* processes when running in debug mode.
+    * Process configuration can depend on Django settings and environment
+      variables, and have paths relative to your project and/or apps.
+    * Apps can provide default process configurations, which projects can
+      then tweak or override as needed.
+
+
+
 Configuration
 -------------
 
@@ -51,13 +69,9 @@ Celery task daemon::
 
     [program:webserver]
     command={{ PROJECT_DIR }}/manage.py runserver --noreload
-    autostart=true
-    autorestart=true
  
     [program:celeryd]
     command={{ PROJECT_DIR }}/manage.py celeryd -l info
-    autostart=true
-    autorestart=true
 
 
 Now when you run the "supervisor" management command, it will detect this
@@ -77,8 +91,6 @@ server when debugging but run under FCGI in production::
     {% else %}
     command={{ PROJECT_DIR }}/manage.py runfcgi host=127.0.0.1 port=8025
     {% endif %}
-    autostart=true
-    autorestart=true
  
 
 For more flexibility, django-supervisor also supports per-application config
@@ -97,7 +109,7 @@ application, and tweak or override them on a per-project basis.
 Usage
 -----
 
-Django-supervisor provides a new Django manangement command named "supervise"
+Django-supervisor provides a new Django manangement command named "supervisor"
 which allows you to control all of the processes belonging to your project.
 
 When run without arguments, it will spawn supervisord to launch and monitor
@@ -114,12 +126,13 @@ file shown in the previous section::
 
 By default the "supervisor" command will stay in the foreground and print
 status updates to the console.  Pass the --daemonize option to have it 
-run in the background.
+run in the background.  You can also tweak its behaviour using all of
+supervisord's standard options in the config file.
 
 Once the supervisor is up and running, you can interact with it to control the
 running processes.  Running "manage.py supervisor shell" will launch the
 interactive supervisorctl command shell.  From here you can view process
-status, and start/stop individual processes::
+status and start/stop/restart individual processes::
 
     $ python myproject/manage.py supervisor shell
     celeryd                          RUNNING    pid 4799, uptime 0:03:17
@@ -157,29 +170,100 @@ command-line::
     $
 
 
+For details of all the available management commands, consult the supervisord
+documentation.
 
-Advantages
-----------
 
-Django-supervisor is admittedly quite a thin layer on top of the wonderful
-functionality provided by supervisord.  But by integrating tightly with
-Django's management scripts you gain several advantages:
+Extra Goodies
+-------------
 
-    * manage.py remains the single point of control for running your project.
-    * Process configuration lives and is managed inside your project directory.
-    * Process configuration can depend on Django settings and environment
-      variables, and have paths relative to your project and/or apps.
-    * Apps can provide default process configurations, which projects can
-      then tweak or override as needed.
-    * Running all those processes is just as easy in development as it
-      is in production.
+Django-supervisor provides some extra niceties on top of the configuration
+language of supervisord.
 
 
+Templating
+~~~~~~~~~~
+
+All supervisord.conf files are rendered through Django's templating system.
+This allows you to interpolate values from the settings or environment, and
+conditionally switch processes on or off.  The template context for each
+configuration file contains the following variables:
+
+    :PROJECT_DIR:    the top-level directory of your project (i.e. the
+                     directory containing your manage.py script).
+
+    :APP_DIR:        for app-provided config files, the top-level directory
+                     containing the application code.
+
+    :settings:       the Django settings module, as seen by your code.
+
+    :environ:        the os.environ dict, as seen by your code.
+
+
+Defaults, Overrides and Excludes
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+Django-supervisor recognises some special config-file options that are useful
+when merging multiple app-specific and project-specific configuration files.
+
+The [program:__defaults__] section can be used to provide default options
+for all other [program] sections.  These options will only be used if none
+of the config files found by django-supervisor provide that option for
+a specific program.
+
+The [program:__overrides__] section can be used to override options for all
+configured programs.  These options will be applied to all processes regardless
+of what any other config file has to say.
+
+Finally, you can completely disable a [program] section by setting the option
+"exclude" to true.  This is mostly useful for disabling process definitions
+provided by a third-party application.
+
+Here's an example config file that shows them all in action::
+
+    ; We want all programs to redirect stderr by default,
+    ; unless specifically configured otherwise.
+    [program:__defaults__]
+    redirect_stderr=true
+
+    ; We force all programs to run as user "nobody"
+    [program:__overrides__]
+    user=nobody
+
+    ; Django-supervisord ships with a default configuration for celerybeat.
+    ; We don't use it, so remove it from the config.
+    [program:celerybeat]
+    exclude=true
+
+
+Autorestart
+~~~~~~~~~~~
+
+When running in debug mode, django-supervisor automatically defines a process
+named "autorestart".  This is very similar to the auto-reloading feature of
+the Django development server, but works across all configured processes.
+For example, this will let you automatically restart both the dev server and
+celeryd whenever your code changes.
+
+To switch off the autorestart process, just exclude it in your project config
+file like so::
+
+    [program:autorestart]
+    exclude=true
+
+
+More Info
+---------
+
+There aren't any more docs online yet.  Sorry.  I'm working on a little tutorial
+and some examples, but I need to actually *use* the project a little more
+first to make sure it all fits together the way I want...
+
 """
 
 __ver_major__ = 0
 __ver_minor__ = 1
-__ver_patch__ = 0
+__ver_patch__ = 1
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
